@@ -36,6 +36,9 @@ srec_cat_arglex3::srec_cat_arglex3(int argc, char **argv) :
         { "-Line_Length", token_line_length, },
         { "-Line_Termination", token_line_termination, },
         { "-End_Of_Line", token_line_termination, },
+        { "-Output_Block_Size", token_output_block_size, },
+        { "-Output_Block_Packing", token_output_block_packing, },
+        { "-Output_Block_Alignment", token_output_block_align, },
 
         //
         // This option is intentionally undocumented.  It is preserved
