@@ -1,6 +1,6 @@
 //
 //      srecord - manipulate eprom load files
-//      Copyright (C) 1998-2002, 2005-2008 Peter Miller
+//      Copyright (C) 1998-2002, 2005-2010 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 //      <http://www.gnu.org/licenses/>.
 //
 
-#include <lib/interval.h>
-#include <lib/srec/arglex.h>
-#include <lib/srec/input/file.h>
-#include <lib/srec/memory.h>
-#include <lib/srec/record.h>
+#include <srecord/interval.h>
+#include <srecord/arglex/tool.h>
+#include <srecord/input/file.h>
+#include <srecord/memory.h>
+#include <srecord/record.h>
 
 #include <cctype>
 #include <iostream>
@@ -33,11 +33,11 @@
 int
 main(int argc, char **argv)
 {
-    srec_arglex cmdline(argc, argv);
+    srecord::arglex_tool cmdline(argc, argv);
     cmdline.token_first();
-    typedef std::vector<srec_input::pointer> infile_t;
+    typedef std::vector<srecord::input::pointer> infile_t;
     infile_t infile;
-    while (cmdline.token_cur() != arglex::token_eoln)
+    while (cmdline.token_cur() != srecord::arglex::token_eoln)
     {
         switch (cmdline.token_cur())
         {
@@ -45,10 +45,10 @@ main(int argc, char **argv)
             cmdline.default_command_line_processing();
             continue;
 
-        case srec_arglex::token_paren_begin:
-        case srec_arglex::token_string:
-        case srec_arglex::token_stdio:
-        case srec_arglex::token_generator:
+        case srecord::arglex_tool::token_paren_begin:
+        case srecord::arglex_tool::token_string:
+        case srecord::arglex_tool::token_stdio:
+        case srecord::arglex_tool::token_generator:
             infile.push_back(cmdline.get_input());
             continue;
         }
@@ -62,24 +62,24 @@ main(int argc, char **argv)
     //
     for (infile_t::iterator it = infile.begin(); it != infile.end(); ++it)
     {
-        srec_input::pointer ifp = *it;
+        srecord::input::pointer ifp = *it;
         if (infile.size() > 1)
         {
             std::cout << std::endl;
             std::cout << ifp->filename() << ":" << std::endl;
         }
         std::cout << "Format: " << ifp->get_file_format_name() << std::endl;
-        srec_record record;
-        interval range;
+        srecord::record record;
+        srecord::interval range;
         while (ifp->read(record))
         {
             switch (record.get_type())
             {
-            case srec_record::type_header:
+            case srecord::record::type_header:
                 if (record.get_length() < 1)
                     break;
                 std::cout << "Header: \"";
-                for (int j = 0; j < record.get_length(); ++j)
+                for (size_t j = 0; j < record.get_length(); ++j)
                 {
                     int c = record.get_data(j) & 127;
                     if (c == '\\' || c == '"')
@@ -96,20 +96,21 @@ main(int argc, char **argv)
                 std::cout << "\"" << std::endl;
                 break;
 
-            case srec_record::type_data:
+            case srecord::record::type_data:
                 range +=
-                    interval
+                    srecord::interval
                     (
                         record.get_address(),
                         record.get_address() + record.get_length()
                     );
                 break;
 
-            case srec_record::type_execution_start_address:
+            case srecord::record::type_execution_start_address:
                 {
                     std::cout << "Execution Start Address: ";
+                    unsigned long addr = record.get_address();
                     char buf[16];
-                    snprintf(buf, sizeof(buf), "%08lX", record.get_address());
+                    snprintf(buf, sizeof(buf), "%08lX", addr);
                     std::cout << buf << std::endl;
                 }
                 break;
@@ -132,7 +133,7 @@ main(int argc, char **argv)
         bool first_line = true;
         for (;;)
         {
-            interval tmp = range;
+            srecord::interval tmp = range;
             tmp.first_interval_only();
             if (first_line)
             {
@@ -142,9 +143,11 @@ main(int argc, char **argv)
             else
                 std::cout << "        ";
             char buf[32];
-            snprintf(buf, sizeof(buf), "%0*lX", prec, tmp.get_lowest());
+            unsigned long lo = tmp.get_lowest();
+            snprintf(buf, sizeof(buf), "%0*lX", prec, lo);
             std::cout << buf << " - ";
-            snprintf(buf, sizeof(buf), "%0*lX", prec, tmp.get_highest() - 1);
+            unsigned long hi = tmp.get_highest() - 1;
+            snprintf(buf, sizeof(buf), "%0*lX", prec, hi);
             std::cout << buf << std::endl;
             range -= tmp;
             if (range.empty())
