@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2001, 2002, 2006-2010 Peter Miller
+// Copyright (C) 2001, 2002, 2006-2011 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -79,8 +79,8 @@ srecord::output_file_dec_binary::write(const srecord::record &record)
     case srecord::record::type_data:
         if (record.get_length() < 1)
             return;
-        if (record.get_address() + record.get_length() > (1UL << 16))
-            data_address_too_large(record);
+        if (!record.address_range_fits_into_n_bits(16))
+            data_address_too_large(record, 16);
 
 #if 0
         //
@@ -197,3 +197,11 @@ srecord::output_file_dec_binary::format_name()
 {
     return "DEC-Binary";
 }
+
+
+bool
+srecord::output_file_dec_binary::is_binary(void)
+    const
+{
+    return true;
+}
