@@ -32,7 +32,7 @@ if test $? -ne 0; then no_result; fi
 cat > test.ok << 'fubar'
 Format: Motorola S-Record
 Header: "HDR"
-Start:  00000000
+Execution Start Address: 00000000
 Data:   0000 - 000D
 fubar
 if test $? -ne 0; then no_result; fi
