@@ -34,7 +34,7 @@ if test $? -ne 0; then no_result; fi
 cat > test.ok << 'fubar'
 Format: Motorola S-Record
 Header: "HDR"
-Start:  00000000
+Execution Start Address: 00000000
 Data:   0000 - 000D
 fubar
 if test $? -ne 0; then no_result; fi
@@ -56,7 +56,7 @@ if test $? -ne 0; then no_result; fi
 
 cat > test.ok << 'fubar'
 Format: Intel Hexadecimal (MCS-86)
-Start:  00000000
+Execution Start Address: 00000000
 Data:   0000 - 000D
 fubar
 if test $? -ne 0; then no_result; fi
